@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright 2015 Sam Yaple
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -295,7 +293,9 @@ def generate_module():
                                                            'shareable']),
         cap_add=dict(required=False, type='list', default=list()),
         security_opt=dict(required=False, type='list', default=list()),
-        pid_mode=dict(required=False, type='str', choices=['host', '']),
+        pid_mode=dict(required=False, type='str', choices=['',
+                                                           'host',
+                                                           'private']),
         cgroupns_mode=dict(required=False, type='str',
                            choices=['private', 'host']),
         privileged=dict(required=False, type='bool', default=False),
